@@ -1,5 +1,4 @@
 # @author Augustin Mortier
-# @email augustinm@met.no
 # @desc A-Profiles - ProfilesData class
 
 import copy
@@ -106,7 +105,7 @@ class ProfilesData:
             >>> # snr image
             >>> profiles.plot(var='snr',vmin=0, vmax=3, cmap='Greys_r')
 
-            .. figure:: ../../examples/images/snr.png
+            .. figure:: ../../docs/_static/images/snr.png
                 :scale: 50 %
                 :alt: snr
 
@@ -170,13 +169,13 @@ class ProfilesData:
             >>> profiles.data.attenuated_backscatter_0.attrs.gaussian_filter
             0.50
 
-            .. figure:: ../../examples/images/attenuated_backscatter.png
+            .. figure:: ../../docs/_static/images/attenuated_backscatter.png
                 :scale: 50 %
                 :alt: before filtering
 
                 Before gaussian filtering.
 
-            .. figure:: ../../examples/images/gaussian_filter.png
+            .. figure:: ../../docs/_static/images/gaussian_filter.png
                 :scale: 50 %
                 :alt: after gaussian filtering
 
@@ -260,13 +259,13 @@ class ProfilesData:
             >>> profiles.data.attenuated_backscatter_0.extrapolation_low_layers_altitude_agl
             150
 
-            .. figure:: ../../examples/images/lowest.png
+            .. figure:: ../../docs/_static/images/lowest.png
                 :scale: 50 %
                 :alt: before extrapolation
 
                 Before extrapolation.
 
-            .. figure:: ../../examples/images/lowest_extrap.png
+            .. figure:: ../../docs/_static/images/lowest_extrap.png
                 :scale: 50 %
                 :alt: after desaturation
 
@@ -366,13 +365,13 @@ class ProfilesData:
             >>> profiles.data.attenuated_backscatter_0.desaturated
             True
 
-            .. figure:: ../../examples/images/saturated.png
+            .. figure:: ../../docs/_static/images/saturated.png
                 :scale: 50 %
                 :alt: before desaturation
 
                 Before desaturation.
 
-            .. figure:: ../../examples/images/desaturated.png
+            .. figure:: ../../docs/_static/images/desaturated.png
                 :scale: 50 %
                 :alt: after desaturation
 
@@ -421,7 +420,7 @@ class ProfilesData:
 
     def plot(
         self, var="attenuated_backscatter_0", datetime=None, zref="agl", zmin=None, zmax=None, vmin=None, vmax=None, log=False,
-        show_foc=False, show_pbl=False, show_clouds=False, cmap="coolwarm", **kwargs
+        show_foc=False, show_pbl=False, show_clouds=False, cmap="coolwarm", show_fig=True, save_fig=None, **kwargs
     ):
         """Plotting method.
         Depending on the variable selected, this method will plot an image, a single profile or a time series of the requested variable.
@@ -440,6 +439,8 @@ class ProfilesData:
             - show_pbl (bool, optional): Show PBL height retrievals. Defaults to `False`.
             - show_clouds (bool, optional): Show clouds retrievals. Defaults to `False`.
             - cmap (str, optional): Matplotlib colormap. Defaults to `'coolwarm'`.
+            - show_fig (bool, optional): Show Figure. Defaults to `True`.
+            - save_fig (str, optional): Path of the saved figure. Defaults to `None`.
         """
 
         # check if var is available
@@ -454,11 +455,11 @@ class ProfilesData:
         if datetime is None:
             # check dimension of var
             if len(list(self.data[var].dims)) == 2:
-                apro.plot.image.plot(self.data, var, zref, zmin, zmax, vmin, vmax, log, show_foc, show_pbl, show_clouds, cmap=cmap)
+                apro.plot.image.plot(self.data, var, zref, zmin, zmax, vmin, vmax, log, show_foc, show_pbl, show_clouds, cmap, show_fig, save_fig)
             else:
-                apro.plot.timeseries.plot(self.data, var, **kwargs)
+                apro.plot.timeseries.plot(self.data, var, show_fig, save_fig, **kwargs)
         else:
-            apro.plot.profile.plot(self.data, datetime, var, zref, zmin, zmax, vmin, vmax, log, show_foc, show_pbl, show_clouds)
+            apro.plot.profile.plot(self.data, datetime, var, zref, zmin, zmax, vmin, vmax, log, show_foc, show_pbl, show_clouds, show_fig, save_fig)
     
     def write(self, base_dir='examples/data/V-Profiles/', verbose=False):
         """Calls :meth:`aprofiles.io.write_profiles.write()`."""
